/***************************************************************************
*   Copyright (C) 2003 by Hideki Ikemoto                                  *
*   ikemo@wakaba.jp                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#ifndef FAVORITETHREADSTEST_H
#define FAVORITETHREADSTEST_H

#include <cppunit/extensions/HelperMacros.h>
#include "../favoritethreads.h"

/**
@author Hideki Ikemoto
*/
class FavoriteThreadsTest : public CppUnit::TestFixture
{
    CPPUNIT_TEST_SUITE( FavoriteThreadsTest );
    CPPUNIT_TEST( testToXML );
    CPPUNIT_TEST( testThreads );
    CPPUNIT_TEST( testReplace );
    CPPUNIT_TEST_SUITE_END();

    QString m_xml;
public:
    void setUp();
    void tearDown();

    void testToXML();
    void testThreads();
    void testReplace();
};

#endif
